@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2011-2012 Sérgio Martins <iamsergio@gmail.com>
+   Copyright (C) 2011-2013 Sérgio Martins <iamsergio@gmail.com>
 
    This library is free software; you can redistribute it and/or modify it
    under the terms of the GNU Library General Public License as published by
@@ -17,12 +17,14 @@
    02110-1301, USA.
 */
 
-#include "blockalarmsattribute.h"
 #include "etmcalendar.h"
 #include "etmcalendar_p.h"
+#include "blockalarmsattribute.h"
 #include "incidencefetchjob_p.h"
 #include "calendarmodel_p.h"
 #include "kcolumnfilterproxymodel_p.h"
+#include "calfilterproxymodel_p.h"
+#include "utils_p.h"
 
 #include <akonadi/item.h>
 #include <akonadi/session.h>
@@ -31,9 +33,9 @@
 #include <akonadi/itemfetchscope.h>
 #include <akonadi/entitydisplayattribute.h>
 #include <akonadi/entitymimetypefiltermodel.h>
-#include <akonadi/entitytreemodel.h>
+#include <akonadi/collectionfilterproxymodel.h>
 #include <KSelectionProxyModel>
-#include <kcheckableproxymodel.h>
+#include <KDescendantsProxyModel>
 
 #include <QSortFilterProxyModel>
 #include <QItemSelectionModel>
@@ -44,10 +46,14 @@ using namespace KCalCore;
 //TODO: implement batchAdding
 
 ETMCalendarPrivate::ETMCalendarPrivate( ETMCalendar *qq ) : CalendarBasePrivate( qq )
-                                                            , mETM( 0 )
-                                                            , mFilteredETM( 0 )
-                                                            , mCheckableProxyModel( 0 )
-                                                            , q( qq )
+                                                          , mETM( 0 )
+                                                          , mFilteredETM( 0 )
+                                                          , mCheckableProxyModel( 0 )
+                                                          , mCollectionProxyModel( 0 )
+                                                          , mCalFilterProxyModel( 0 )
+                                                          , mSelectionProxy( 0 )
+                                                          , mCollectionFilteringEnabled( true )
+                                                          , q( qq )
 {
 }
 
@@ -56,7 +62,7 @@ void ETMCalendarPrivate::init()
   Akonadi::Session *session = new Akonadi::Session( "ETMCalendar", q );
   Akonadi::ChangeRecorder *monitor = new Akonadi::ChangeRecorder( q );
   connect( monitor, SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)),
-           q, SIGNAL(collectionChanged(Akonadi::Collection,QSet<QByteArray>)) );
+           SLOT(onCollectionChanged(Akonadi::Collection,QSet<QByteArray>)) );
 
   Akonadi::ItemFetchScope scope;
   scope.fetchFullPayload( true );
@@ -75,6 +81,10 @@ void ETMCalendarPrivate::init()
 
   setupFilteredETM();
 
+  connect( q, SIGNAL(filterChanged()), SLOT(onFilterChanged()) );
+
+  connect( mETM, SIGNAL(collectionPopulated(Akonadi::Collection::Id)),
+           SLOT(onCollectionPopulated(Akonadi::Collection::Id)) );
   connect( mETM, SIGNAL(rowsInserted(QModelIndex,int,int)),
            SLOT(onRowsInserted(QModelIndex,int,int)) );
   connect( mETM, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
@@ -98,39 +108,64 @@ void ETMCalendarPrivate::init()
   loadFromETM();
 }
 
+void ETMCalendarPrivate::onCollectionChanged(const Akonadi::Collection &collection,
+                                             const QSet<QByteArray> &attributeNames)
+{
+    Q_ASSERT(collection.isValid());
+    // Is the collection changed to read-only, we update all Incidences
+    if (attributeNames.contains("AccessRights")) {
+        Akonadi::Item::List items = q->items();
+        foreach (const Akonadi::Item &item, items) {
+            if (item.storageCollectionId() == collection.id()) {
+                KCalCore::Incidence::Ptr incidence = CalendarUtils::incidence(item);
+                if (incidence)
+                    incidence->setReadOnly(!(collection.rights() & Akonadi::Collection::CanChangeItem));
+            }
+        }
+    }
+
+    emit q->collectionChanged(collection, attributeNames);
+}
+
 void ETMCalendarPrivate::setupFilteredETM()
 {
-  // Our calendar tree must be sorted.
-  QSortFilterProxyModel *sortFilterProxy = new QSortFilterProxyModel( this );
-  sortFilterProxy->setObjectName( "Sort" );
-  sortFilterProxy->setDynamicSortFilter( true );
-  sortFilterProxy->setSortCaseSensitivity( Qt::CaseInsensitive );
-  sortFilterProxy->setSourceModel( mETM );
-
   // We're only interested in the CollectionTitle column
   KColumnFilterProxyModel *columnFilterProxy = new KColumnFilterProxyModel( this );
-  columnFilterProxy->setSourceModel( sortFilterProxy );
+  columnFilterProxy->setSourceModel( mETM );
   columnFilterProxy->setVisibleColumn( CalendarModel::CollectionTitle );
   columnFilterProxy->setObjectName( "Remove columns" );
 
+  mCollectionProxyModel = new Akonadi::CollectionFilterProxyModel( this );
+  mCollectionProxyModel->setObjectName( "Only show collections" );
+  mCollectionProxyModel->setDynamicSortFilter( true );
+  mCollectionProxyModel->addMimeTypeFilter( QString::fromLatin1( "text/calendar" ) );
+  mCollectionProxyModel->setExcludeVirtualCollections( true );
+  mCollectionProxyModel->setSortCaseSensitivity( Qt::CaseInsensitive );
+  mCollectionProxyModel->setSourceModel( columnFilterProxy );
+
   // Keep track of selected items.
-  QItemSelectionModel* selectionModel = new QItemSelectionModel( columnFilterProxy );
+  QItemSelectionModel* selectionModel = new QItemSelectionModel( mCollectionProxyModel );
   selectionModel->setObjectName( "Calendar Selection Model" );
 
   // Make item selection work by means of checkboxes.
-  mCheckableProxyModel = new KCheckableProxyModel( this );
+  mCheckableProxyModel = new CheckableProxyModel( this );
   mCheckableProxyModel->setSelectionModel( selectionModel );
-  mCheckableProxyModel->setSourceModel( columnFilterProxy );
+  mCheckableProxyModel->setSourceModel( mCollectionProxyModel );
   mCheckableProxyModel->setObjectName( "Add checkboxes" );
 
-  KSelectionProxyModel* selectionProxy = new KSelectionProxyModel( selectionModel, /**parent=*/this );
-  selectionProxy->setObjectName( "Only show items of selected collection" );
-  selectionProxy->setFilterBehavior( KSelectionProxyModel::ChildrenOfExactSelection );
-  selectionProxy->setSourceModel( mETM );
+  mSelectionProxy = new KSelectionProxyModel( selectionModel, /**parent=*/this );
+  mSelectionProxy->setObjectName( "Only show items of selected collection" );
+  mSelectionProxy->setFilterBehavior( KSelectionProxyModel::ChildrenOfExactSelection );
+  mSelectionProxy->setSourceModel( mETM );
+
+  mCalFilterProxyModel = new CalFilterProxyModel( this );
+  mCalFilterProxyModel->setFilter( q->filter() );
+  mCalFilterProxyModel->setSourceModel( mSelectionProxy );
+  mCalFilterProxyModel->setObjectName( "KCalCore::CalFilter filtering" );
 
   mFilteredETM = new Akonadi::EntityMimeTypeFilterModel( this );
+  mFilteredETM->setSourceModel( mCalFilterProxyModel );
   mFilteredETM->setHeaderGroup( Akonadi::EntityTreeModel::ItemListHeaders );
-  mFilteredETM->setSourceModel( selectionProxy );
   mFilteredETM->setSortRole( CalendarModel::SortRole );
   mFilteredETM->setObjectName( "Show headers" );
 }
@@ -147,11 +182,30 @@ void ETMCalendarPrivate::loadFromETM()
 void ETMCalendarPrivate::clear()
 {
   mCollectionMap.clear();
- 
-  itemsRemoved( mItemById.values() );
-  Q_ASSERT( mItemById.isEmpty() );
-  Q_ASSERT( mItemIdByUid.isEmpty() );
 
+  itemsRemoved( mItemById.values() );
+
+  if (!mItemById.isEmpty()) {
+    // This never happens
+    kDebug() << "This shouldnt happen: !mItemById.isEmpty()";
+    foreach(Akonadi::Item::Id id, mItemById.keys()) {
+      kDebug() << "Id = " << id;
+    }
+
+    mItemById.clear();
+    //Q_ASSERT(false); // TODO: discover why this happens
+  }
+
+  if (!mItemIdByUid.isEmpty()) {
+    // This never happens
+    kDebug() << "This shouldnt happen: !mItemIdByUid.isEmpty()";
+    foreach(const QString &uid, mItemIdByUid.keys()) {
+      kDebug() << "uid: " << uid;
+    }
+    mItemIdByUid.clear();
+    //Q_ASSERT(false);
+  }
+  mParentUidToChildrenUid.clear();
   //m_virtualItems.clear();
 }
 
@@ -212,10 +266,18 @@ Akonadi::Item ETMCalendarPrivate::itemFromIndex( const QModelIndex &idx )
 
 void ETMCalendarPrivate::itemsAdded( const Akonadi::Item::List &items )
 {
-  foreach( const Akonadi::Item &item, items ) {
-    internalInsert( item );
+  if ( !items.isEmpty() ) {
+    foreach( const Akonadi::Item &item, items ) {
+      internalInsert( item );
+    }
+
+    Akonadi::Collection::Id id = items.first().storageCollectionId();
+    if ( mPopulatedCollectionIds.contains( id ) ) {
+      // If the collection isn't populated yet, it will be send later
+      // Saves some cpu cycles
+      emit q->calendarChanged();
+    }
   }
-  emit q->calendarChanged();
 }
 
 void ETMCalendarPrivate::itemsRemoved( const Akonadi::Item::List &items )
@@ -245,6 +307,12 @@ void ETMCalendarPrivate::onRowsInserted( const QModelIndex &index,
     emit q->collectionsAdded( collections );
 }
 
+void ETMCalendarPrivate::onCollectionPopulated( Akonadi::Collection::Id id )
+{
+  mPopulatedCollectionIds.insert( id );
+  emit q->calendarChanged();
+}
+
 void ETMCalendarPrivate::onRowsRemoved( const QModelIndex &index, int start, int end )
 {
   Akonadi::Collection::List collections = collectionsFromModel( mETM, index, start, end );
@@ -309,12 +377,18 @@ void ETMCalendarPrivate::onDataChangedInFilteredModel( const QModelIndex &topLef
   int row = i.row();
   while ( row <= endRow ) {
     const Akonadi::Item item = itemFromIndex( i );
-    if ( item.isValid() ) {
+    if ( item.isValid() && item.hasPayload<KCalCore::Incidence::Ptr>() ) {
       Incidence::Ptr newIncidence = item.payload<KCalCore::Incidence::Ptr>();
       Q_ASSERT( newIncidence );
       Q_ASSERT( !newIncidence->uid().isEmpty() );
-      IncidenceBase::Ptr existingIncidence = q->incidence( newIncidence->uid() );
-      Q_ASSERT( existingIncidence );
+      IncidenceBase::Ptr existingIncidence = q->incidence( newIncidence->uid(), newIncidence->recurrenceId() );
+      if ( !existingIncidence ) {
+        // The item changed it's UID, update our maps.
+        // The Google resource, for example, changes the UID when we create incidences.
+        handleUidChange( item, newIncidence->instanceIdentifier() );
+        existingIncidence = q->incidence( newIncidence->uid(), newIncidence->recurrenceId() );
+        Q_ASSERT( existingIncidence );
+      }
 
       // The item needs updating too, revision changed.
       mItemById.insert( item.id(), item );
@@ -339,7 +413,12 @@ void ETMCalendarPrivate::onRowsAboutToBeRemovedInFilteredModel( const QModelInde
   itemsRemoved( itemsFromModel( mFilteredETM, index, start, end ) );
 }
 
-ETMCalendar::ETMCalendar() : CalendarBase( new ETMCalendarPrivate( this ) )
+void ETMCalendarPrivate::onFilterChanged()
+{
+  mCalFilterProxyModel->setFilter( q->filter() );
+}
+
+ETMCalendar::ETMCalendar( QObject *parent ) : CalendarBase( new ETMCalendarPrivate( this ), parent )
 {
   Q_D( ETMCalendar );
   d->init();
@@ -370,18 +449,12 @@ bool ETMCalendar::hasRight( const Akonadi::Item &item, Akonadi::Collection::Righ
   return col.rights() & right;
 }
 
-QAbstractItemModel *ETMCalendar::filteredModel() const
+QAbstractItemModel *ETMCalendar::model() const
 {
   Q_D( const ETMCalendar );
   return d->mFilteredETM;
 }
 
-QAbstractItemModel *ETMCalendar::unfilteredModel() const
-{
-  Q_D( const ETMCalendar );
-  return d->mETM;
-}
-
 KCheckableProxyModel *ETMCalendar::checkableProxyModel() const
 {
   Q_D( const ETMCalendar );
@@ -398,17 +471,24 @@ KCalCore::Alarm::List ETMCalendar::alarms( const KDateTime &from,
   while ( i.hasNext() ) {
     const Akonadi::Item item = i.next().value();
 
+    BlockAlarmsAttribute *blockedAttr = 0;
+
     if ( excludeBlockedAlarms ) {
       // take the collection from m_collectionMap, because we need the up-to-date collection attrs
       Akonadi::Collection parentCollection = d->mCollectionMap.value( item.storageCollectionId() );
       if ( parentCollection.isValid() && parentCollection.hasAttribute<BlockAlarmsAttribute>() ) {
-        continue;
+        blockedAttr = parentCollection.attribute<BlockAlarmsAttribute>();
+        if ( blockedAttr->isAlarmTypeBlocked( Alarm::Audio ) && blockedAttr->isAlarmTypeBlocked( Alarm::Display )
+             && blockedAttr->isAlarmTypeBlocked( Alarm::Email ) && blockedAttr->isAlarmTypeBlocked( Alarm::Procedure ) )
+        {
+          continue;
+        }
       }
     }
 
     KCalCore::Incidence::Ptr incidence;
     if ( item.isValid() && item.hasPayload<KCalCore::Incidence::Ptr>() ) {
-      incidence = item.payload<KCalCore::Incidence::Ptr>();
+      incidence = KCalCore::Incidence::Ptr(item.payload<KCalCore::Incidence::Ptr>()->clone());
     } else {
       continue;
     }
@@ -417,6 +497,19 @@ KCalCore::Alarm::List ETMCalendar::alarms( const KDateTime &from,
       continue;
     }
 
+    if ( blockedAttr ) {
+      // Remove all blocked types of alarms
+      Q_FOREACH ( const KCalCore::Alarm::Ptr &alarm, incidence->alarms() ) {
+        if ( blockedAttr->isAlarmTypeBlocked( alarm->type() ) ) {
+          incidence->removeAlarm( alarm );
+        }
+      }
+    }
+
+    if ( incidence->alarms().isEmpty() ) {
+      continue;
+    }
+
     if ( incidence->recurs() ) {
       appendRecurringAlarms( alarmList, incidence, from, to );
     } else {
@@ -426,5 +519,35 @@ KCalCore::Alarm::List ETMCalendar::alarms( const KDateTime &from,
   return alarmList;
 }
 
+Akonadi::EntityTreeModel *ETMCalendar::entityTreeModel() const
+{
+  Q_D( const ETMCalendar );
+  return d->mETM;
+}
+
+void ETMCalendar::setCollectionFilteringEnabled( bool enable )
+{
+  Q_D( ETMCalendar );
+  if ( d->mCollectionFilteringEnabled != enable ) {
+    d->mCollectionFilteringEnabled = enable;
+    if ( enable ) {
+      d->mSelectionProxy->setSourceModel( d->mETM );
+      QAbstractItemModel *oldModel = d->mCalFilterProxyModel->sourceModel();
+      d->mCalFilterProxyModel->setSourceModel( d->mSelectionProxy );
+      delete qobject_cast<KDescendantsProxyModel *>( oldModel );
+    } else {
+      KDescendantsProxyModel *flatner = new KDescendantsProxyModel( this );
+      flatner->setSourceModel( d->mETM );
+      d->mCalFilterProxyModel->setSourceModel( flatner );
+    }
+  }
+}
+
+bool ETMCalendar::collectionFilteringEnabled() const
+{
+  Q_D( const ETMCalendar );
+  return d->mCollectionFilteringEnabled;
+}
+
 #include "etmcalendar.moc"
 #include "etmcalendar_p.moc"
