@@ -31,16 +31,33 @@ class KCheckableProxyModel;
 
 namespace Akonadi {
 
+class EntityTreeModel;
 class ETMCalendarPrivate;
 class CollectionSelection;
 
+/**
+ * @short A KCalCore::Calendar that uses an EntityTreeModel to populate itself.
+ *
+ * All non-idempotent KCalCore::Calendar methods interact with Akonadi.
+ * If you need a need a non-persistent calendar use FetchJobCalendar.
+ *
+ * ETMCalendar allows to be populated with only a subset of your calendar items,
+ * by using a KCheckableProxyModel to specify which collections to be used
+ * and/or by setting a KCalCore::CalFilter.
+ *
+ * @see FetchJobCalendar
+ * @see CalendarBase
+ *
+ * @author Sérgio Martins <iamsergio@gmail.com>
+ * @since 4.11
+ */
 class AKONADI_CALENDAR_EXPORT ETMCalendar : public CalendarBase
 {
   Q_OBJECT
 public:
 
   enum CollectionColumn {
-    CollectionTitle=0,
+    CollectionTitle = 0,
     CollectionColumnCount
   };
 
@@ -49,13 +66,18 @@ public:
   /**
     * Constructs a new ETMCalendar. Loading begins immediately, asynchronously.
     */
-  explicit ETMCalendar();
+  ETMCalendar( QObject *parent = 0 );
 
   /**
     * Destroys this ETMCalendar.
     */
   ~ETMCalendar();
 
+  /**
+   * Returns the collection having @p id.
+   * Use this instead of creating a new collection, the returned collection will have
+   * the correct right, name, display name, etc all set.
+   */
   Akonadi::Collection collection( Akonadi::Collection::Id ) const;
 
   /**
@@ -65,16 +87,47 @@ public:
 
   /**
     * This is an overloaded function.
+    * @param uid the identifier for the incidence to check for rights
+    * @param right the access right to check for
     * @see hasRight()
     */
   bool hasRight( const QString &uid, Akonadi::Collection::Right right ) const;
 
-  QAbstractItemModel *unfilteredModel() const;
-  QAbstractItemModel *filteredModel() const;
+  /**
+   * Returns the KCheckableProxyModel used to select from which collections should
+   * the calendar be populated from.
+   */
   KCheckableProxyModel *checkableProxyModel() const;
 
   /**
-    * Returns all alarms occuring in a specified time interval.
+   * Convenience method to access the contents of this KCalCore::Calendar through
+   * a QAIM interface.
+   *
+   * Like through calendar interface, the model only items of selected collections.
+   * To select or unselect collections, see checkableProxyModel().
+   *
+   * @see checkableProxyModel()
+   * @see entityTreeModel()
+   */
+  QAbstractItemModel *model() const;
+
+  /**
+   * Returns the underlying EntityTreeModel.
+   *
+   * For most uses, you'll want model() or the KCalCore::Calendar interface instead.
+   *
+   * It contains every item and collection with calendar mime type, doesn't have
+   * KCalCore filtering and doesn't honour any collection selection.
+   *
+   * This method is exposed for performance reasons only, so you can reuse it,
+   * since it's resource savy.
+   *
+   * @see model()
+   */
+  Akonadi::EntityTreeModel *entityTreeModel() const;
+
+  /**
+    * Returns all alarms occurring in a specified time interval.
     * @param from start date of interval
     * @param to end data of interval
     * @param exludeBlockedAlarms if true, alarms belonging to blocked collections aren't returned.
@@ -86,6 +139,21 @@ public:
                                 const KDateTime &to,
                                 bool excludeBlockedAlarms ) const;
 
+  /**
+   * Enable or disable collection filtering.
+   * If true, the calendar will only contain items of selected collections.
+   * @param enable enables collection filtering if set as @c true
+   * @see checkableProxyModel()
+   * @see collectionFilteringEnabled()
+   */
+  void setCollectionFilteringEnabled( bool enable );
+
+  /**
+   * Returns whether collection filtering is enabled. Default is true.
+   * @see setCollectionFilteringEnabled()
+   */
+  bool collectionFilteringEnabled() const;
+
 Q_SIGNALS:
   /**
     * This signal is emitted if a collection has been changed (properties or attributes).
