@@ -25,13 +25,13 @@
 #include "calendarbase.h"
 
 #include <akonadi/item.h>
-#include <KDateTime>
-#include <KSystemTimeZones>
+#include <KDE/KDateTime>
+#include <KDE/KSystemTimeZones>
 
 namespace Akonadi {
 class FetchJobCalendarPrivate;
 /**
-* @short A Calendar that gets populated by a one time IncidenceFetchJob.
+* @short A KCalCore::Calendar that uses a one time IncidenceFetchJob to populate itself.
 *
 * If you want a persistent calendar ( which monitors Akonadi for changes )
 * use an ETMCalendar.
@@ -52,7 +52,7 @@ public:
     * Creates a new FetchJobCalendar. Loading begins asynchronously.
     * @see loadFinished()
     */
-  explicit FetchJobCalendar();
+  explicit FetchJobCalendar( QObject *parent = 0 );
 
   /**
     * Destroys this FetchJobCalendar.
@@ -72,6 +72,9 @@ Q_SIGNALS:
     * @param errorMessage if @p success is false, contains the error message
     */
   void loadFinished( bool success, const QString &errorMessage );
+
+private:
+  Q_DECLARE_PRIVATE( FetchJobCalendar )
 };
 
 }
