@@ -27,7 +27,7 @@
 #include <akonadi/entitytreemodel.h>
 #include <kcombobox.h>
 #include <kicon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QtCore/QTimer>
 #include <QAbstractItemView>
