@@ -28,9 +28,10 @@
 #include <akonadi/mimetypechecker.h>
 #include <kabc/addressee.h>
 #include <kabc/contactgroup.h>
+#include <kicon.h>
 #include <kaction.h>
 #include <kactioncollection.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
 
 #include <QtCore/QPointer>
@@ -440,10 +441,12 @@ class StandardContactActionManager::Private
         return;
       }
 
-      Akonadi::ContactEditorDialog dlg( Akonadi::ContactEditorDialog::CreateMode, mParentWidget );
-      dlg.setDefaultAddressBook( selectedCollection() );
-
-      dlg.exec();
+      QPointer<Akonadi::ContactEditorDialog> dlg =
+        new Akonadi::ContactEditorDialog(
+          Akonadi::ContactEditorDialog::CreateMode, mParentWidget );
+      dlg->setDefaultAddressBook( selectedCollection() );
+      dlg->setAttribute( Qt::WA_DeleteOnClose );
+      dlg->show();
     }
 
     void slotCreateContactGroup()
@@ -452,10 +455,12 @@ class StandardContactActionManager::Private
         return;
       }
 
-      Akonadi::ContactGroupEditorDialog dlg( Akonadi::ContactGroupEditorDialog::CreateMode, mParentWidget );
-      dlg.setDefaultAddressBook( selectedCollection() );
-
-      dlg.exec();
+      QPointer<Akonadi::ContactGroupEditorDialog> dlg =
+        new Akonadi::ContactGroupEditorDialog(
+          Akonadi::ContactGroupEditorDialog::CreateMode, mParentWidget );
+      dlg->setDefaultAddressBook( selectedCollection() );
+      dlg->setAttribute( Qt::WA_DeleteOnClose );
+      dlg->show();
     }
 
     void slotEditItem()
@@ -483,16 +488,29 @@ class StandardContactActionManager::Private
       }
 
       if ( Akonadi::MimeTypeChecker::isWantedItem( item, KABC::Addressee::mimeType() ) ) {
-        Akonadi::ContactEditorDialog dlg( Akonadi::ContactEditorDialog::EditMode, mParentWidget );
-        dlg.setContact( item );
-        dlg.exec();
+        QPointer<Akonadi::ContactEditorDialog> dlg =
+          new Akonadi::ContactEditorDialog(
+            Akonadi::ContactEditorDialog::EditMode, mParentWidget );
+        connect( dlg, SIGNAL(error(QString)),
+                 mParent, SLOT(slotContactEditorError(QString)) );
+        dlg->setContact( item );
+        dlg->setAttribute( Qt::WA_DeleteOnClose );
+        dlg->show();
       } else if ( Akonadi::MimeTypeChecker::isWantedItem( item, KABC::ContactGroup::mimeType() ) ) {
-        Akonadi::ContactGroupEditorDialog dlg( Akonadi::ContactGroupEditorDialog::EditMode, mParentWidget );
-        dlg.setContactGroup( item );
-        dlg.exec();
+        QPointer<Akonadi::ContactGroupEditorDialog> dlg =
+          new Akonadi::ContactGroupEditorDialog(
+            Akonadi::ContactGroupEditorDialog::EditMode, mParentWidget );
+        dlg->setContactGroup( item );
+        dlg->setAttribute( Qt::WA_DeleteOnClose );
+        dlg->show();
       }
     }
 
+    void slotContactEditorError(const QString& error)
+    {
+        KMessageBox::error(mParentWidget, i18n("Contact cannot be stored: %1", error), i18n("Failed to store contact"));
+    }
+
     KActionCollection *mActionCollection;
     QWidget *mParentWidget;
     StandardActionManager *mGenericManager;
