@@ -27,7 +27,7 @@
 
 #include <kdebug.h>
 #include <kglobal.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QtCore/QEventLoop>
 #include <QtCore/QCoreApplication>
