@@ -31,7 +31,7 @@ namespace Akonadi {
 class JobPrivate
 {
   public:
-    JobPrivate( Job *parent )
+    explicit JobPrivate( Job *parent )
       : q_ptr( parent ),
         mCurrentSubJob( 0 ),
         mSession( 0 ),
@@ -71,6 +71,9 @@ class JobPrivate
     /**
      * Notify following jobs about item revision changes.
      * This is used to avoid phantom conflicts between pipelined modify jobs on the same item.
+     * @param itemID the id of the item which has changed
+     * @param oldRevision the old item revision
+     * @param newRevision the new item revision
      */
     void itemRevisionChanged( Akonadi::Item::Id itemId, int oldRevision, int newRevision );
 
