@@ -144,7 +144,7 @@ class AKONADI_EXPORT Monitor : public QObject
 
     /**
      * Sets whether all items shall be monitored.
-     *
+     * @param monitored sets all items as monitored if set as @c true
      * Note that if a session is being ignored, this takes precedence over
      * setAllMonitored() on that session.
      */
@@ -303,7 +303,7 @@ class AKONADI_EXPORT Monitor : public QObject
     /**
      * Sets the session used by the Monitor to communicate with the %Akonadi server.
      * If not set, the Akonadi::Session::defaultSession is used.
-     *
+     * @param session the session to be set
      * @since 4.4
      */
     void setSession( Akonadi::Session *session );
@@ -319,7 +319,7 @@ class AKONADI_EXPORT Monitor : public QObject
      * Allows to enable/disable collection move translation. If enabled (the default), move
      * notifications are auotmatically translated into add/remove notifications if the source/destination
      * is outside of the monitored collection hierarchy.
-     *
+     * @param enabled enables collection move translation if set as @c true
      * @since 4.9
      */
     void setCollectionMoveTranslationEnabled( bool enabled );
@@ -333,6 +333,17 @@ class AKONADI_EXPORT Monitor : public QObject
      */
     void itemChanged( const Akonadi::Item &item, const QSet<QByteArray> &partIdentifiers );
 
+    /**
+     * This signal is emitted if flags of monitored items have changed.
+     *
+     * @param items Items that were changed
+     * @param addedFlags Flags that have been added to each item in @p items
+     * @param removedFlags Flags that have been removed from each item in @p items
+     * @since 4.11
+     */
+    void itemsFlagsChanged( const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags,
+                                                              const QSet<QByteArray> &removedFlags );
+
     /**
      * This signal is emitted if a monitored item has been moved between two collections
      *
@@ -343,6 +354,18 @@ class AKONADI_EXPORT Monitor : public QObject
     void itemMoved( const Akonadi::Item &item, const Akonadi::Collection &collectionSource,
                                                const Akonadi::Collection &collectionDestination );
 
+    /**
+     * This is signal is emitted when multiple monitored items have been moved between two collections
+     *
+     * @param items Moved items
+     * @param collectionSource The collection the items have been moved from.
+     * @param collectionDestination The collection the items have been moved to.
+     *
+     * @since 4.11
+     */
+    void itemsMoved( const Akonadi::Item::List &items, const Akonadi::Collection &collectionSource,
+                                                       const Akonadi::Collection &collectionDestination );
+
     /**
      * This signal is emitted if an item has been added to a monitored collection in the Akonadi storage.
      *
@@ -361,6 +384,16 @@ class AKONADI_EXPORT Monitor : public QObject
      */
     void itemRemoved( const Akonadi::Item &item );
 
+    /**
+     * This signal is emitted if monitored items have been removed from Akonadi
+     * storage of items have been removed from a monitored collection.
+     *
+     * @param items Removed items
+     *
+     * @since 4.11
+     */
+    void itemsRemoved( const Akonadi::Item::List &items );
+
     /**
      * This signal is emitted if a reference to an item is added to a virtual collection.
      * @param item The linked item.
@@ -370,6 +403,16 @@ class AKONADI_EXPORT Monitor : public QObject
      */
     void itemLinked( const Akonadi::Item &item, const Akonadi::Collection &collection );
 
+    /**
+     * This signal is emitted if a reference to multiple items is added to a virtual collection
+     *
+     * @param items The linked items
+     * @param collection The collections the items are linked to
+     *
+     * @since 4.11
+     */
+    void itemsLinked( const Akonadi::Item::List &items, const Akonadi::Collection &collection );
+
     /**
      * This signal is emitted if a reference to an item is removed from a virtual collection.
      * @param item The unlinked item.
@@ -379,6 +422,16 @@ class AKONADI_EXPORT Monitor : public QObject
      */
     void itemUnlinked( const Akonadi::Item &item, const Akonadi::Collection &collection );
 
+    /**
+     * This signal is emitted if a refernece to items is removed from a virtual collection
+     *
+     * @param items The unlinked items
+     * @param collection The collections the items are unlinked from
+     *
+     * @since 4.11
+     */
+    void itemsUnlinked( const Akonadi::Item::List &items, const Akonadi::Collection &collection );
+
     /**
      * This signal is emitted if a new collection has been added to a monitored collection in the Akonadi storage.
      *
@@ -513,7 +566,7 @@ class AKONADI_EXPORT Monitor : public QObject
     Q_PRIVATE_SLOT( d_ptr, void slotSessionDestroyed( QObject* ) )
     Q_PRIVATE_SLOT( d_ptr, void slotStatisticsChangedFinished( KJob* ) )
     Q_PRIVATE_SLOT( d_ptr, void slotFlushRecentlyChangedCollections() )
-    Q_PRIVATE_SLOT( d_ptr, void slotNotify( const Akonadi::NotificationMessage::List& ) )
+    Q_PRIVATE_SLOT( d_ptr, void slotNotify( const Akonadi::NotificationMessageV2::List& ) )
     Q_PRIVATE_SLOT( d_ptr, void dataAvailable() )
     Q_PRIVATE_SLOT( d_ptr, void serverStateChanged( Akonadi::ServerManager::State ) )
     Q_PRIVATE_SLOT( d_ptr, void invalidateCollectionCache( qint64 ) )
