@@ -172,6 +172,9 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      *   }
      *
      * @endcode
+     *
+     * @param argc number of arguments
+     * @param argv string arguments
      */
     template <typename T>
     static int init( int argc, char **argv )
@@ -304,7 +307,10 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     // KDE5: Make it pure virtual, for now can be called only by invokeMethod()
     //       in order to simulate polymorphism
-    QString dumpResourceToString() const { return QString(); }
+    QString dumpResourceToString() const
+    {
+        return QString();
+    }
 
   protected:
     /**
@@ -329,7 +335,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
     /**
      * Call this method from retrieveCollectionAttributes() once the result is available.
      *
-     * @param item The collection whose attributes got retrieved.
+     * @param collection The collection whose attributes got retrieved.
      * @since 4.6
      */
     void collectionAttributesRetrieved( const Collection &collection );
@@ -343,6 +349,17 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     void changeCommitted( const Item &item );
 
+    /**
+     * Resets the dirty flag of all given items and updates remote ids.
+     *
+     * Call whenever you have successfully written changes back to the server.
+     * This implicitly calls changeProcessed().
+     * @param items Changed items
+     *
+     * @since 4.11
+     */
+    void changesCommitted( const Item::List &items );
+
     /**
      * Call whenever you have successfully handled or ignored a collection
      * change notification.
@@ -392,7 +409,8 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
     void collectionsRetrievalDone();
 
     /**
-     * Call this method to supply the full collection listing from the remote server.
+     * Call this method to supply the full collection listing from the remote server. Items not present in the list
+     * will be dropped from the Akonadi database.
      *
      * If the remote server supports incremental listing, it's strongly
      * recommended to use itemsRetrievedIncremental() instead.
@@ -407,6 +425,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      * that way.
      * @deprecated Use setItemStreamingEnabled( true ) + itemsRetrieved[Incremental]()
      * + itemsRetrieved() instead.
+     * @param amount number of items that will arrive in streaming mode
      */
     void setTotalItems( int amount );
 
@@ -419,6 +438,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
 
     /**
      * Set transaction mode for item sync'ing.
+     * @param mode item transaction mode
      * @see Akonadi::ItemSync::TransactionMode
      * @since 4.6
      */
@@ -474,6 +494,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      * The method should be used when the backend indicated that the cached content
      * is no longer valid.
      *
+     * @param collection parent of the content to be invalidated in cache
      * @since 4.8
      */
     void invalidateCache( const Collection &collection );
@@ -532,6 +553,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
     /**
      * Stops the execution of the current task and continues with the next one.
      * Additionally an error message is emitted.
+     * @param error additional error message to be emitted
      */
     void cancelTask( const QString &error );
 
@@ -562,6 +584,7 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      *
      * This should be called in the resource constructor as needed.
      *
+     * @param enable whether to enable use of hierarchical remote identifiers
      * @since 4.4
      */
     void setHierarchicalRemoteIdentifiersEnabled( bool enable );
@@ -613,6 +636,24 @@ class AKONADI_EXPORT ResourceBase : public AgentBase
      */
     QString dumpNotificationListToString() const;
 
+    /**
+     *  Dumps memory usage information to stdout.
+     *  For now it outputs the result of glibc's mallinfo().
+     *  This is useful to check if your memory problems are due to poor management by glibc.
+     *  Look for a high value on fsmblks when interpreting results.
+     *  man mallinfo for more details.
+     *  @since 4.11
+     */
+    void dumpMemoryInfo() const;
+
+    /**
+     *  Returns a string with memory usage information.
+     *  @see dumpMemoryInfo()
+     *
+     *  @since 4.11
+     */
+    QString dumpMemoryInfoToString() const;
+
     /**
      * Dump the state of the scheduler
      * @since 4.8.1
