@@ -366,6 +366,7 @@ void Calendar::setFilter( CalFilter *filter )
   } else {
     d->mFilter = d->mDefaultFilter;
   }
+  emit filterChanged();
 }
 
 CalFilter *Calendar::filter() const
@@ -381,7 +382,7 @@ QStringList Calendar::categories() const
   // the list of categories should be built when reading the file.
   for ( Incidence::List::ConstIterator i = rawInc.constBegin();
         i != rawInc.constEnd(); ++i ) {
-    thisCats = (*i)->categories();
+    thisCats = ( *i )->categories();
     for ( QStringList::ConstIterator si = thisCats.constBegin();
           si != thisCats.constEnd(); ++si ) {
       if ( !cats.contains( *si ) ) {
@@ -434,9 +435,9 @@ Incidence::List Calendar::duplicates( const Incidence::Ptr &incidence )
     Incidence::List vals = values( d->mNotebookIncidences );
     Incidence::List::const_iterator it;
     for ( it = vals.constBegin(); it != vals.constEnd(); ++it ) {
-      if ( ( ( incidence->dtStart() == (*it)->dtStart() ) ||
-             ( !incidence->dtStart().isValid() && !(*it)->dtStart().isValid() ) ) &&
-           ( incidence->summary() == (*it)->summary() ) ) {
+      if ( ( ( incidence->dtStart() == ( *it )->dtStart() ) ||
+             ( !incidence->dtStart().isValid() && !( *it )->dtStart().isValid() ) ) &&
+           ( incidence->summary() == ( *it )->summary() ) ) {
         list.append( *it );
       }
     }
@@ -603,7 +604,7 @@ Event::List Calendar::sortEvents( const Event::List &eventList,
   // Notice we alphabetically presort Summaries first.
   // We do this so comparison "ties" stay in a nice order.
   eventListSorted = eventList;
-  switch( sortField ) {
+  switch ( sortField ) {
   case EventSortUnsorted:
     break;
 
@@ -696,6 +697,41 @@ bool Calendar::deleteIncidence( const Incidence::Ptr &incidence )
   }
 }
 
+Incidence::Ptr Calendar::createException( const Incidence::Ptr &incidence,
+                                          const KDateTime &recurrenceId,
+                                          bool thisAndFuture )
+{
+  Q_ASSERT( recurrenceId.isValid() );
+  if ( !incidence || !incidence->recurs() || !recurrenceId.isValid() ) {
+    return Incidence::Ptr();
+  }
+
+  Incidence::Ptr newInc( incidence->clone() );
+  newInc->setCreated( KDateTime::currentUtcDateTime() );
+  newInc->setRevision(0);
+  //Recurring exceptions are not support for now
+  newInc->clearRecurrence();
+
+  newInc->setRecurrenceId( recurrenceId );
+  newInc->setThisAndFuture( thisAndFuture );
+  newInc->setDtStart(recurrenceId);
+
+  // Calculate and set the new end of the incidence
+  KDateTime end = incidence->dateTime( IncidenceBase::RoleEnd );
+
+  if ( end.isValid() ) {
+    if ( incidence->dtStart().isDateOnly() ) {
+      int offset = incidence->dtStart().daysTo( recurrenceId );
+      end = end.addDays( offset );
+    } else {
+      qint64 offset = incidence->dtStart().secsTo_long( recurrenceId );
+      end = end.addSecs( offset );
+    }
+    newInc->setDateTime( end, IncidenceBase::RoleEnd );
+  }
+  return newInc;
+}
+
 // Dissociate a single occurrence or all future occurrences from a recurring
 // sequence. The new incidence is returned, but not automatically inserted
 // into the calendar, which is left to the calling application.
@@ -850,7 +886,7 @@ Todo::List Calendar::sortTodos( const Todo::List &todoList,
   // Note that To-dos may not have Start DateTimes nor due DateTimes.
 
   todoListSorted = todoList;
-  switch( sortField ) {
+  switch ( sortField ) {
   case TodoSortUnsorted:
     break;
 
@@ -940,7 +976,7 @@ Journal::List Calendar::sortJournals( const Journal::List &journalList,
 
   Journal::List journalListSorted = journalList;
 
-  switch( sortField ) {
+  switch ( sortField ) {
   case JournalSortUnsorted:
     break;
 
@@ -1350,7 +1386,7 @@ void Calendar::setObserversEnabled( bool enabled )
 void Calendar::appendAlarms( Alarm::List &alarms, const Incidence::Ptr &incidence,
                              const KDateTime &from, const KDateTime &to ) const
 {
-  KDateTime preTime = from.addSecs(-1);
+  KDateTime preTime = from.addSecs( -1 );
 
   Alarm::List alarmlist = incidence->alarms();
   for ( int i = 0, iend = alarmlist.count();  i < iend;  ++i ) {
@@ -1380,7 +1416,7 @@ void Calendar::appendRecurringAlarms( Alarm::List &alarms,
     if ( a->enabled() ) {
       if ( a->hasTime() ) {
         // The alarm time is defined as an absolute date/time
-        dt = a->nextRepetition( from.addSecs(-1) );
+        dt = a->nextRepetition( from.addSecs( -1 ) );
         if ( !dt.isValid() || dt > to ) {
           continue;
         }
@@ -1411,12 +1447,12 @@ void Calendar::appendRecurringAlarms( Alarm::List &alarms,
         KDateTime baseStart = incidence->dtStart();
         if ( from > alarmStart ) {
           alarmStart = from;   // don't look earlier than the earliest alarm
-          baseStart = (-offset).end( (-endOffset).end( alarmStart ) );
+          baseStart = ( -offset ).end( ( -endOffset ).end( alarmStart ) );
         }
 
         // Adjust the 'alarmStart' date/time and find the next recurrence at or after it.
         // Treate the two offsets separately in case one is daily and the other not.
-        dt = incidence->recurrence()->getNextDateTime( baseStart.addSecs(-1) );
+        dt = incidence->recurrence()->getNextDateTime( baseStart.addSecs( -1 ) );
         if ( !dt.isValid() ||
              ( dt = endOffset.end( offset.end( dt ) ) ) > to ) // adjust 'dt' to get the alarm time
         {
@@ -1500,4 +1536,3 @@ void Calendar::virtual_hook( int id, void *data )
   Q_ASSERT( false );
 }
 
-#include "calendar.moc"
