@@ -455,11 +455,11 @@ class KCALCORE_EXPORT Calendar : public QObject, public CustomProperties,
     virtual Incidence::List rawIncidences() const;
 
     /**
-      Returns an unfiltered list of all possible instances for this recurring Incidence.
+      Returns an unfiltered list of all exceptions of this recurring incidence.
 
       @param incidence incidence to check
 
-      @return the list of all unfiltered Incidences.
+      @return the list of all unfiltered exceptions.
     */
     virtual Incidence::List instances( const Incidence::Ptr &incidence ) const;
 
@@ -675,10 +675,28 @@ class KCALCORE_EXPORT Calendar : public QObject, public CustomProperties,
       from the recurring Incidences after @a date.
 
       @return a pointer to a new recurring Incidence if @a single is false.
+      @deprecated Use createException()
     */
-    Incidence::Ptr dissociateOccurrence( const Incidence::Ptr &incidence, const QDate &date,
-                                         const KDateTime::Spec &spec,
-                                         bool single = true );
+    KDE_DEPRECATED Incidence::Ptr dissociateOccurrence(
+        const Incidence::Ptr &incidence, const QDate &date,
+        const KDateTime::Spec &spec, bool single = true );
+    /**
+      Creates an exception for an occurrence from a recurring Incidence.
+
+      The returned exception is not automatically inserted into the calendar.
+
+      @param incidence is a pointer to a recurring Incidence.
+      @param recurrenceId specifies the specific occurrence for which the
+      exception applies.
+      @param thisAndFuture specifies if the exception applies only this specific
+      occcurrence or also to all future occurrences.
+
+      @return a pointer to a new exception incidence with @param recurrenceId set.
+      @since 4.11
+    */
+    static Incidence::Ptr createException( const Incidence::Ptr &incidence,
+                                               const KDateTime &recurrenceId,
+                                               bool thisAndFuture = false );
 
   // Event Specific Methods //
 
@@ -1432,6 +1450,13 @@ class KCALCORE_EXPORT Calendar : public QObject, public CustomProperties,
     */
     virtual void virtual_hook( int id, void *data );
 
+  Q_SIGNALS:
+    /**
+      Emitted when setFilter() is called.
+      @since 4.11
+     */
+    void filterChanged();
+
   private:
     //@cond PRIVATE
     class Private;
