@@ -4,6 +4,7 @@
   Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
   Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (c) 2006 David Jarvie <software@astrojar.org.uk>
+  Copyright (C) 2012  Christian Mollekopf <mollekopf@kolabsys.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -355,10 +356,15 @@ icalcomponent *ICalFormatImpl::writeFreeBusy( const FreeBusy::Ptr &freebusy,
   icalcomponent_add_property(
     vfreebusy, icalproperty_new_dtend( writeICalUtcDateTime( freebusy->dtEnd() ) ) );
 
+#ifdef USE_ICAL_1_0
+  icalcomponent_add_property(
+    vfreebusy, icalproperty_new_uid( freebusy->uid().toUtf8() ) );
+#else
   if ( method == iTIPRequest ) {
     icalcomponent_add_property(
       vfreebusy, icalproperty_new_uid( freebusy->uid().toUtf8() ) );
   }
+#endif
 
   //Loops through all the periods in the freebusy object
   Period::List list = freebusy->busyPeriods();
@@ -554,9 +560,13 @@ void ICalFormatImpl::writeIncidence( icalcomponent *parent,
 
   // recurrenceid
   if ( incidence->hasRecurrenceId() ) {
-    icalcomponent_add_property(
-      parent, writeICalDateTimeProperty(
-        ICAL_RECURRENCEID_PROPERTY, incidence->recurrenceId(), tzlist, tzUsedList ) );
+    icalproperty *p = writeICalDateTimeProperty(
+        ICAL_RECURRENCEID_PROPERTY, incidence->recurrenceId(), tzlist, tzUsedList );
+    if ( incidence->thisAndFuture() ) {
+      icalproperty_add_parameter(
+        p, icalparameter_new_range( ICAL_RANGE_THISANDFUTURE ) );
+    }
+    icalcomponent_add_property( parent, p );
   }
 
   RecurrenceRule::List rrules( incidence->recurrence()->rRules() );
@@ -1126,7 +1136,6 @@ Todo::Ptr ICalFormatImpl::readTodo( icalcomponent *vtodo, ICalTimeZones *tzlist
     { // due date/time
       KDateTime kdt = readICalDateTimeProperty( p, tzlist );
       todo->setDtDue( kdt, true );
-      todo->setHasDueDate( true );
       todo->setAllDay( kdt.isDateOnly() );
       break;
     }
@@ -1146,7 +1155,7 @@ Todo::Ptr ICalFormatImpl::readTodo( icalcomponent *vtodo, ICalTimeZones *tzlist
     case ICAL_DTSTART_PROPERTY:
       // Flag that todo has start date. Value is read in by readIncidence().
       if ( todo->comments().filter( "NoStartDate" ).count() ) {
-        todo->setHasStartDate( false );
+        todo->setDtStart( KDateTime() );
       } else {
         todo->setHasStartDate( true );
       }
@@ -1715,6 +1724,11 @@ void ICalFormatImpl::readIncidence( icalcomponent *parent,
       kdt = readICalDateTimeProperty( p, tzlist );
       if ( kdt.isValid() ) {
         incidence->setRecurrenceId( kdt );
+        const icalparameter *param =
+          icalproperty_get_first_parameter( p, ICAL_RANGE_PARAMETER );
+        if ( param && icalparameter_get_range( param ) == ICAL_RANGE_THISANDFUTURE ) {
+          incidence->setThisAndFuture( true );
+        }
       }
       break;
 
