@@ -38,8 +38,8 @@
 #include "calformat.h"
 #include "visitor.h"
 
-#include <QDebug>
-
+#include <QTime>
+#include <KDebug>
 #include <KUrl>
 
 #include <QtCore/QStringList>
@@ -290,6 +290,11 @@ bool IncidenceBase::isReadOnly() const
 void IncidenceBase::setDtStart( const KDateTime &dtStart )
 {
 //  if ( mReadOnly ) return;
+
+  if ( !dtStart.isValid() && type() != IncidenceBase::TypeTodo ) {
+    kWarning() << "Invalid dtStart";
+  }
+
   update();
   d->mDtStart = dtStart;
   d->mAllDay = dtStart.isDateOnly();
@@ -574,7 +579,7 @@ void IncidenceBase::updated()
   if ( d->mUpdateGroupLevel ) {
     d->mUpdatedPending = true;
   } else {
-    KDateTime rid = recurrenceId();
+    const KDateTime rid = recurrenceId();
     foreach ( IncidenceObserver *o, d->mObservers ) {
       o->incidenceUpdated( uid(), rid );
     }
