@@ -152,6 +152,9 @@ class KCALCORE_EXPORT IncidenceBase : public CustomProperties
       RoleDnD                  /**< Role for determining new start and end dates after a DnD */
     };
 
+    /**
+      The different types of incidence fields.
+    */
     enum Field {
       FieldDtStart,         ///> Field representing the DTSTART component.
       FieldDtEnd,           ///> Field representing the DTEND component.
@@ -201,7 +204,7 @@ class KCALCORE_EXPORT IncidenceBase : public CustomProperties
 
         /**
           The IncidenceObserver interface.
-	  This function is called before any changes are made.
+          This function is called before any changes are made.
           @param uid is the string containing the incidence @ref uid.
           @param recurrenceId is possible recurrenceid of incidence.
         */
@@ -209,7 +212,7 @@ class KCALCORE_EXPORT IncidenceBase : public CustomProperties
 
         /**
           The IncidenceObserver interface.
-	  This function is called after changes are completed.
+          This function is called after changes are completed.
           @param uid is the string containing the incidence @ref uid.
           @param recurrenceId is possible recurrenceid of incidence.
         */
@@ -652,6 +655,7 @@ class KCALCORE_EXPORT IncidenceBase : public CustomProperties
 
     /**
        Marks Field @p field as dirty.
+       @param field is the Field type to mark as dirty.
        @see dirtyFields()
     */
     void setFieldDirty( IncidenceBase::Field field );
@@ -670,7 +674,6 @@ class KCALCORE_EXPORT IncidenceBase : public CustomProperties
 
     /**
       Constructs an IncidenceBase as a copy of another IncidenceBase object.
-
       @param ib is the IncidenceBase to copy.
     */
     IncidenceBase( const IncidenceBase &ib );
@@ -713,4 +716,7 @@ class KCALCORE_EXPORT IncidenceBase : public CustomProperties
 
 }
 
+Q_DECLARE_METATYPE( KCalCore::IncidenceBase * )
+Q_DECLARE_METATYPE( KCalCore::IncidenceBase::Ptr )
+
 #endif
