@@ -35,6 +35,7 @@
 #include "memorycalendar.h"
 
 #include <KDebug>
+#include <QDate>
 
 using namespace KCalCore;
 
@@ -57,6 +58,7 @@ class KCalCore::MemoryCalendar::Private
     MemoryCalendar *q;
     QString mFileName;                     // filename where calendar is stored
     CalFormat *mFormat;                    // calendar format
+    QString mIncidenceBeingUpdated;        //  Instance identifier of Incidence currently beeing updated
 
     /**
      * List of all incidences.
@@ -64,6 +66,11 @@ class KCalCore::MemoryCalendar::Private
      */
     QMap<IncidenceBase::IncidenceType, QMultiHash<QString, Incidence::Ptr> > mIncidences;
 
+    /**
+     * Has all incidences, indexed by identifier.
+     */
+    QHash<QString,KCalCore::Incidence::Ptr> mIncidencesByIdentifier;
+
     /**
      * List of all deleted incidences.
      * First indexed by incidence->type(), then by incidence->uid();
@@ -83,7 +90,7 @@ class KCalCore::MemoryCalendar::Private
      */
     QMap<IncidenceBase::IncidenceType, QMultiHash<QString, IncidenceBase::Ptr> > mIncidencesForDate;
 
-    void insertIncidence( Incidence::Ptr incidence );
+    void insertIncidence( const Incidence::Ptr &incidence );
 
     Incidence::Ptr incidence( const QString &uid,
                               const IncidenceBase::IncidenceType type,
@@ -96,6 +103,7 @@ class KCalCore::MemoryCalendar::Private
     void deleteAllIncidences( const IncidenceBase::IncidenceType type );
 
 };
+//@endcond
 
 MemoryCalendar::MemoryCalendar( const KDateTime::Spec &timeSpec )
   : Calendar( timeSpec ),
@@ -123,6 +131,7 @@ void MemoryCalendar::close()
   deleteAllEvents();
   deleteAllTodos();
   deleteAllJournals();
+  d->mIncidencesByIdentifier.clear();
 
   d->mDeletedIncidences.clear();
 
@@ -140,6 +149,7 @@ bool MemoryCalendar::deleteIncidence( const Incidence::Ptr &incidence )
   const Incidence::IncidenceType type = incidence->type();
   const QString uid = incidence->uid();
   if ( d->mIncidences[type].remove( uid, incidence ) ) {
+    d->mIncidencesByIdentifier.remove( incidence->instanceIdentifier() );
     setModified( true );
     notifyIncidenceDeleted( incidence );
     d->mDeletedIncidences[type].insert( uid, incidence );
@@ -179,6 +189,7 @@ bool MemoryCalendar::deleteIncidenceInstances( const Incidence::Ptr &incidence )
   return true;
 }
 
+//@cond PRIVATE
 void MemoryCalendar::Private::deleteAllIncidences( const Incidence::IncidenceType incidenceType )
 {
   QHashIterator<QString, Incidence::Ptr>i( mIncidences[incidenceType] );
@@ -236,13 +247,13 @@ MemoryCalendar::Private::deletedIncidence( const QString &uid,
   return Incidence::Ptr();
 }
 
-//@cond PRIVATE
-void MemoryCalendar::Private::insertIncidence( Incidence::Ptr incidence )
+void MemoryCalendar::Private::insertIncidence( const Incidence::Ptr &incidence )
 {
   const QString uid = incidence->uid();
   const Incidence::IncidenceType type = incidence->type();
   if ( !mIncidences[type].contains( uid, incidence ) ) {
     mIncidences[type].insert( uid, incidence );
+    mIncidencesByIdentifier.insert( incidence->instanceIdentifier(), incidence );
     const KDateTime dt = incidence->dateTime( Incidence::RoleCalendarHashing );
     if ( dt.isValid() ) {
       mIncidencesForDate[type].insert( dt.date().toString(), incidence );
@@ -260,10 +271,10 @@ void MemoryCalendar::Private::insertIncidence( Incidence::Ptr incidence )
 
 bool MemoryCalendar::addIncidence( const Incidence::Ptr &incidence )
 {
-  notifyIncidenceAdded( incidence );
-
   d->insertIncidence( incidence );
 
+  notifyIncidenceAdded( incidence );
+
   incidence->registerObserver( this );
 
   setupRelations( incidence );
@@ -509,10 +520,16 @@ void MemoryCalendar::incidenceUpdate( const QString &uid, const KDateTime &recur
   Incidence::Ptr inc = incidence( uid, recurrenceId );
 
   if ( inc ) {
-    const Incidence::IncidenceType type = inc->type();
-    const KDateTime dt = inc->dateTime( Incidence::RoleCalendarHashing );
+    if ( !d->mIncidenceBeingUpdated.isEmpty() ) {
+      kWarning() << "Incidence::update() called twice without an updated() call in between.";
+    }
 
+    // Save it so we can detect changes to uid or recurringId.
+    d->mIncidenceBeingUpdated = inc->instanceIdentifier();
+
+    const KDateTime dt = inc->dateTime( Incidence::RoleCalendarHashing );
     if ( dt.isValid() ) {
+      const Incidence::IncidenceType type = inc->type();
       d->mIncidencesForDate[type].remove( dt.date().toString(), inc );
     }
   }
@@ -523,16 +540,25 @@ void MemoryCalendar::incidenceUpdated( const QString &uid, const KDateTime &recu
   Incidence::Ptr inc = incidence( uid, recurrenceId );
 
   if ( inc ) {
-    KDateTime nowUTC = KDateTime::currentUtcDateTime();
-    inc->setLastModified( nowUTC );
+
+    if ( d->mIncidenceBeingUpdated.isEmpty() ) {
+      kWarning() << "Incidence::updated() called twice without an update() call in between.";
+    } else if ( inc->instanceIdentifier() != d->mIncidenceBeingUpdated ) {
+      // Instance identifier changed, update our hash table
+      d->mIncidencesByIdentifier.remove( d->mIncidenceBeingUpdated );
+      d->mIncidencesByIdentifier.insert( inc->instanceIdentifier(), inc );
+    }
+
+    d->mIncidenceBeingUpdated = QString();
+
+    inc->setLastModified( KDateTime::currentUtcDateTime() );
     // we should probably update the revision number here,
     // or internally in the Event itself when certain things change.
     // need to verify with ical documentation.
 
-    const Incidence::IncidenceType type = inc->type();
     const KDateTime dt = inc->dateTime( Incidence::RoleCalendarHashing );
-
     if ( dt.isValid() ) {
+      const Incidence::IncidenceType type = inc->type();
       d->mIncidencesForDate[type].insert( dt.date().toString(), inc );
     }
 
@@ -806,6 +832,11 @@ Journal::List MemoryCalendar::rawJournalsForDate( const QDate &date ) const
   return journalList;
 }
 
+Incidence::Ptr MemoryCalendar::instance(const QString &identifier) const
+{
+    return d->mIncidencesByIdentifier.value(identifier);
+}
+
 void MemoryCalendar::virtual_hook( int id, void *data )
 {
   Q_UNUSED( id );
