@@ -19,7 +19,7 @@
 
 #include "getmetadatajob.h"
 
-#include <KDE/KLocale>
+#include <KDE/KLocalizedString>
 #include <KDE/KDebug>
 
 #include "metadatajobbase_p.h"
@@ -214,4 +214,3 @@ QMap<QByteArray, QMap<QByteArray, QByteArray> > GetMetaDataJob::allMetaData(cons
   Q_D( const GetMetaDataJob );
   return d->metadata[mailBox];
 }
-
