@@ -24,7 +24,7 @@
 #include <kdeversion.h>
 #include <sonnet/globals.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <kconfiggroup.h>
 #include <kurl.h>
@@ -59,6 +59,7 @@ Identity::Identity( const QString &id, const QString &fullName,
   setProperty( s_organization, organization );
   setProperty( s_replyto, replyToAddr );
   setDictionary( Sonnet::defaultLanguageName() );
+  setProperty( s_disabledFcc, false );
 }
 
 Identity::~Identity()
@@ -83,7 +84,11 @@ bool Identity::isNull() const
       ++i;
       continue;
     }
-
+    // Take into account that disableFcc == false for a null identity 
+    if( i.key() == s_disabledFcc && i.value().toBool() == false ) {
+      ++i;
+      continue;
+    }
     // The uoid is 0 by default, so ignore this
     if ( !( i.key() == s_uoid && i.value().toUInt() == 0 ) ) {
       if ( !i.value().isNull() ||
@@ -190,7 +195,8 @@ QDataStream &KPIMIdentities::operator<<
          << i.preferredCryptoMessageFormat()
          << i.cc()
          << i.attachVcard()
-         << i.autocorrectionLanguage();
+         << i.autocorrectionLanguage()
+         << i.disabledFcc();
 
 
 }
@@ -223,7 +229,8 @@ QDataStream &KPIMIdentities::operator>>
   >> i.mPropertiesMap[s_prefcrypt]
   >> i.mPropertiesMap[s_cc]
   >> i.mPropertiesMap[s_attachVcard]
-  >> i.mPropertiesMap[s_autocorrectionLanguage];
+  >> i.mPropertiesMap[s_autocorrectionLanguage]
+  >> i.mPropertiesMap[s_disabledFcc];
 
   i.setProperty( s_uoid, uoid );
   return stream;
@@ -683,3 +690,19 @@ void Identity::setAutocorrectionLanguage(const QString& language)
 {
   setProperty( s_autocorrectionLanguage, language );
 }
+
+
+bool Identity::disabledFcc() const
+{
+  const QVariant var = property(QLatin1String( s_disabledFcc ));
+  if(var.isNull()) {
+     return false;
+  } else {
+     return var.toBool();
+  }
+}
+
+void Identity::setDisabledFcc(bool disable)
+{
+  setProperty( s_disabledFcc, disable );
+}
